This part of the project documentation focuses on
an **information-oriented** approach. Use it as a
reference for the technical implementation of the
`mlpForecaster` project code.

::: metrics.deterministic